@@ -584,7 +584,8 @@ class EpubBuilder(StandaloneHTMLBuilder):
                     # we always have JS and potentially OpenSearch files, don't
                     # always warn about them
                     if ext not in ('.js', '.xml'):
-                        self.warn('unknown mimetype for %s, ignoring' % filename)
+                        self.warn('unknown mimetype for %s, ignoring' % filename,
+                                  type='epub', subtype='unknown_project_files')
                     continue
                 filename = filename.replace(os.sep, '/')
                 projectfiles.append(self.file_template % {
@@ -828,3 +829,9 @@ def setup(app):
     app.add_config_value('epub_max_image_width', 0, 'env')
     app.add_config_value('epub_show_urls', 'inline', 'html')
     app.add_config_value('epub_use_index', lambda self: self.html_use_index, 'html')
+
+    return {
+        'version': 'builtin',
+        'parallel_read_safe': True,
+        'parallel_write_safe': True,
+    }
