@@ -6,7 +6,7 @@
     Allow graphviz-formatted graphs to be included in Sphinx-generated
     documents inline.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -25,6 +25,7 @@ from docutils.statemachine import ViewList
 import sphinx
 from sphinx.errors import SphinxError
 from sphinx.locale import _
+from sphinx.util.i18n import search_image_for_language
 from sphinx.util.osutil import ensuredir, ENOENT, EPIPE, EINVAL
 from sphinx.util.compat import Directive
 
@@ -36,12 +37,14 @@ class GraphvizError(SphinxError):
     category = 'Graphviz error'
 
 
-class graphviz(nodes.General, nodes.Element):
+class graphviz(nodes.General, nodes.Inline, nodes.Element):
     pass
 
 
 def figure_wrapper(directive, node, caption):
     figure_node = nodes.figure('', node)
+    if 'align' in node:
+        figure_node['align'] = node.attributes.pop('align')
 
     parsed = nodes.Element()
     directive.state.nested_parse(ViewList([caption], source=''),
@@ -54,6 +57,10 @@ def figure_wrapper(directive, node, caption):
     return figure_node
 
 
+def align_spec(argument):
+    return directives.choice(argument, ('left', 'center', 'right'))
+
+
 class Graphviz(Directive):
     """
     Directive to insert arbitrary dot markup.
@@ -64,8 +71,10 @@ class Graphviz(Directive):
     final_argument_whitespace = False
     option_spec = {
         'alt': directives.unchanged,
+        'align': align_spec,
         'inline': directives.flag,
         'caption': directives.unchanged,
+        'graphviz_dot': directives.unchanged,
     }
 
     def run(self):
@@ -76,14 +85,12 @@ class Graphviz(Directive):
                     'Graphviz directive cannot have both content and '
                     'a filename argument', line=self.lineno)]
             env = self.state.document.settings.env
-            rel_filename, filename = env.relfn2path(self.arguments[0])
+            argument = search_image_for_language(self.arguments[0], env)
+            rel_filename, filename = env.relfn2path(argument)
             env.note_dependency(rel_filename)
             try:
-                fp = codecs.open(filename, 'r', 'utf-8')
-                try:
+                with codecs.open(filename, 'r', 'utf-8') as fp:
                     dotcode = fp.read()
-                finally:
-                    fp.close()
             except (IOError, OSError):
                 return [document.reporter.warning(
                     'External Graphviz file %r not found or reading '
@@ -96,13 +103,18 @@ class Graphviz(Directive):
                     line=self.lineno)]
         node = graphviz()
         node['code'] = dotcode
-        node['options'] = []
+        node['options'] = {}
+        if 'graphviz_dot' in self.options:
+            node['options']['graphviz_dot'] = self.options['graphviz_dot']
         if 'alt' in self.options:
             node['alt'] = self.options['alt']
-        node['inline'] = 'inline' in self.options
+        if 'align' in self.options:
+            node['align'] = self.options['align']
+        if 'inline' in self.options:
+            node['inline'] = True
 
         caption = self.options.get('caption')
-        if caption and not node['inline']:
+        if caption:
             node = figure_wrapper(self, node, caption)
 
         return [node]
@@ -118,21 +130,28 @@ class GraphvizSimple(Directive):
     final_argument_whitespace = False
     option_spec = {
         'alt': directives.unchanged,
+        'align': align_spec,
         'inline': directives.flag,
         'caption': directives.unchanged,
+        'graphviz_dot': directives.unchanged,
     }
 
     def run(self):
         node = graphviz()
         node['code'] = '%s %s {\n%s\n}\n' % \
                        (self.name, self.arguments[0], '\n'.join(self.content))
-        node['options'] = []
+        node['options'] = {}
+        if 'graphviz_dot' in self.options:
+            node['options']['graphviz_dot'] = self.options['graphviz_dot']
         if 'alt' in self.options:
             node['alt'] = self.options['alt']
-        node['inline'] = 'inline' in self.options
+        if 'align' in self.options:
+            node['align'] = self.options['align']
+        if 'inline' in self.options:
+            node['inline'] = True
 
         caption = self.options.get('caption')
-        if caption and not node['inline']:
+        if caption:
             node = figure_wrapper(self, node, caption)
 
         return [node]
@@ -140,8 +159,8 @@ class GraphvizSimple(Directive):
 
 def render_dot(self, code, options, format, prefix='graphviz'):
     """Render graphviz code into a PNG or PDF output file."""
-    hashkey = (code + str(options) +
-               str(self.builder.config.graphviz_dot) +
+    graphviz_dot = options.get('graphviz_dot', self.builder.config.graphviz_dot)
+    hashkey = (code + str(options) + str(graphviz_dot) +
                str(self.builder.config.graphviz_dot_args)).encode('utf-8')
 
     fname = '%s-%s.%s' % (prefix, sha1(hashkey).hexdigest(), format)
@@ -151,8 +170,8 @@ def render_dot(self, code, options, format, prefix='graphviz'):
     if path.isfile(outfn):
         return relfn, outfn
 
-    if hasattr(self.builder, '_graphviz_warned_dot') or \
-       hasattr(self.builder, '_graphviz_warned_ps2pdf'):
+    if (hasattr(self.builder, '_graphviz_warned_dot') and
+       self.builder._graphviz_warned_dot.get(graphviz_dot)):
         return None, None
 
     ensuredir(path.dirname(outfn))
@@ -161,9 +180,8 @@ def render_dot(self, code, options, format, prefix='graphviz'):
     if isinstance(code, text_type):
         code = code.encode('utf-8')
 
-    dot_args = [self.builder.config.graphviz_dot]
+    dot_args = [graphviz_dot]
     dot_args.extend(self.builder.config.graphviz_dot_args)
-    dot_args.extend(options)
     dot_args.extend(['-T' + format, '-o' + outfn])
     if format == 'png':
         dot_args.extend(['-Tcmapx', '-o%s.map' % outfn])
@@ -173,9 +191,10 @@ def render_dot(self, code, options, format, prefix='graphviz'):
         if err.errno != ENOENT:   # No such file or directory
             raise
         self.builder.warn('dot command %r cannot be run (needed for graphviz '
-                          'output), check the graphviz_dot setting' %
-                          self.builder.config.graphviz_dot)
-        self.builder._graphviz_warned_dot = True
+                          'output), check the graphviz_dot setting' % graphviz_dot)
+        if not hasattr(self.builder, '_graphviz_warned_dot'):
+            self.builder._graphviz_warned_dot = {}
+        self.builder._graphviz_warned_dot[graphviz_dot] = True
         return None, None
     try:
         # Graphviz may close standard input when an error occurs,
@@ -197,6 +216,15 @@ def render_dot(self, code, options, format, prefix='graphviz'):
     return relfn, outfn
 
 
+def warn_for_deprecated_option(self, node):
+    if hasattr(self.builder, '_graphviz_warned_inline'):
+        return
+
+    if 'inline' in node:
+        self.builder.warn(':inline: option for graphviz is deprecated since version 1.4.0.')
+        self.builder._graphviz_warned_inline = True
+
+
 def render_dot_html(self, node, code, options, prefix='graphviz',
                     imgcls=None, alt=None):
     format = self.builder.config.graphviz_output_format
@@ -209,13 +237,6 @@ def render_dot_html(self, node, code, options, prefix='graphviz',
         self.builder.warn('dot code %r: ' % code + str(exc))
         raise nodes.SkipNode
 
-    inline = node.get('inline', False)
-    if inline:
-        wrapper = 'span'
-    else:
-        wrapper = 'p'
-
-    self.body.append(self.starttag(node, wrapper, CLASS='graphviz'))
     if fname is None:
         self.body.append(self.encode(code))
     else:
@@ -227,11 +248,11 @@ def render_dot_html(self, node, code, options, prefix='graphviz',
             <p class="warning">%s</p></object>\n''' % (fname, alt)
             self.body.append(svgtag)
         else:
-            mapfile = open(outfn + '.map', 'rb')
-            try:
+            if 'align' in node:
+                self.body.append('<div align="%s" class="align-%s">' %
+                                 (node['align'], node['align']))
+            with open(outfn + '.map', 'rb') as mapfile:
                 imgmap = mapfile.readlines()
-            finally:
-                mapfile.close()
             if len(imgmap) == 2:
                 # nothing in image map (the lines are <map> and </map>)
                 self.body.append('<img src="%s" alt="%s" %s/>\n' %
@@ -242,12 +263,14 @@ def render_dot_html(self, node, code, options, prefix='graphviz',
                 self.body.append('<img src="%s" alt="%s" usemap="#%s" %s/>\n' %
                                  (fname, alt, mapname, imgcss))
                 self.body.extend([item.decode('utf-8') for item in imgmap])
+            if 'align' in node:
+                self.body.append('</div>\n')
 
-    self.body.append('</%s>\n' % wrapper)
     raise nodes.SkipNode
 
 
 def html_visit_graphviz(self, node):
+    warn_for_deprecated_option(self, node)
     render_dot_html(self, node, node['code'], node['options'])
 
 
@@ -258,19 +281,31 @@ def render_dot_latex(self, node, code, options, prefix='graphviz'):
         self.builder.warn('dot code %r: ' % code + str(exc))
         raise nodes.SkipNode
 
-    inline = node.get('inline', False)
-    if inline:
+    is_inline = self.is_inline(node)
+    if is_inline:
         para_separator = ''
     else:
         para_separator = '\n'
 
     if fname is not None:
+        post = None
+        if not is_inline and 'align' in node:
+            if node['align'] == 'left':
+                self.body.append('{')
+                post = '\\hspace*{\\fill}}'
+            elif node['align'] == 'right':
+                self.body.append('{\\hspace*{\\fill}')
+                post = '}'
         self.body.append('%s\\includegraphics{%s}%s' %
                          (para_separator, fname, para_separator))
+        if post:
+            self.body.append(post)
+
     raise nodes.SkipNode
 
 
 def latex_visit_graphviz(self, node):
+    warn_for_deprecated_option(self, node)
     render_dot_latex(self, node, node['code'], node['options'])
 
 
@@ -286,10 +321,12 @@ def render_dot_texinfo(self, node, code, options, prefix='graphviz'):
 
 
 def texinfo_visit_graphviz(self, node):
+    warn_for_deprecated_option(self, node)
     render_dot_texinfo(self, node, node['code'], node['options'])
 
 
 def text_visit_graphviz(self, node):
+    warn_for_deprecated_option(self, node)
     if 'alt' in node.attributes:
         self.add_text(_('[graph: %s]') % node['alt'])
     else:
@@ -298,6 +335,7 @@ def text_visit_graphviz(self, node):
 
 
 def man_visit_graphviz(self, node):
+    warn_for_deprecated_option(self, node)
     if 'alt' in node.attributes:
         self.body.append(_('[graph: %s]') % node['alt'])
     else:
