@@ -5,7 +5,7 @@
 
     Format colored console output.
 
-    :copyright: Copyright 2007-2014 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -13,26 +13,35 @@ import os
 import sys
 import re
 
+try:
+    # check if colorama is installed to support color on Windows
+    import colorama
+except ImportError:
+    colorama = None
+
 _ansi_re = re.compile('\x1b\\[(\\d\\d;){0,2}\\d\\dm')
 codes = {}
 
+
 def get_terminal_width():
     """Borrowed from the py lib."""
     try:
-        import termios, fcntl, struct
+        import termios
+        import fcntl
+        import struct
         call = fcntl.ioctl(0, termios.TIOCGWINSZ,
                            struct.pack('hhhh', 0, 0, 0, 0))
         height, width = struct.unpack('hhhh', call)[:2]
         terminal_width = width
-    except (SystemExit, KeyboardInterrupt):
-        raise
-    except:
+    except Exception:
         # FALLBACK
         terminal_width = int(os.environ.get('COLUMNS', 80)) - 1
     return terminal_width
 
 
 _tw = get_terminal_width()
+
+
 def term_width_line(text):
     if not codes:
         # if no coloring, don't output fancy backspaces
@@ -41,7 +50,11 @@ def term_width_line(text):
         # codes are not displayed, this must be taken into account
         return text.ljust(_tw + len(text) - len(_ansi_re.sub('', text))) + '\r'
 
+
 def color_terminal():
+    if sys.platform == 'win32' and colorama is not None:
+        colorama.init()
+        return True
     if not hasattr(sys.stdout, 'isatty'):
         return False
     if not sys.stdout.isatty():
@@ -55,19 +68,29 @@ def color_terminal():
 
 
 def nocolor():
+    if sys.platform == 'win32' and colorama is not None:
+        colorama.deinit()
     codes.clear()
 
+
 def coloron():
     codes.update(_orig_codes)
 
+
 def colorize(name, text):
     return codes.get(name, '') + text + codes.get('reset', '')
 
+
+def strip_colors(s):
+    return re.compile('\x1b.*?m').sub('', s)
+
+
 def create_color_func(name):
     def inner(text):
         return colorize(name, text)
     globals()[name] = inner
 
+
 _attrs = {
     'reset':     '39;49;00m',
     'bold':      '01m',
@@ -77,7 +100,7 @@ _attrs = {
     'blink':     '05m',
 }
 
-for _name, _value in list(_attrs.items()):
+for _name, _value in _attrs.items():
     codes[_name] = '\x1b[' + _value
 
 _colors = [
@@ -92,8 +115,8 @@ _colors = [
 ]
 
 for i, (dark, light) in enumerate(_colors):
-    codes[dark] = '\x1b[%im' % (i+30)
-    codes[light] = '\x1b[%i;01m' % (i+30)
+    codes[dark] = '\x1b[%im' % (i + 30)
+    codes[light] = '\x1b[%i;01m' % (i + 30)
 
 _orig_codes = codes.copy()
 
