@@ -62,17 +62,12 @@ def apply_source_workaround(node):
     if node.source and node.rawsource:
         return
 
-    # workaround: docutils-0.10.0 or older's nodes.caption for nodes.figure
-    # and nodes.title for nodes.admonition doesn't have source, line.
-    # this issue was filed to Docutils tracker:
-    # sf.net/tracker/?func=detail&aid=3599485&group_id=38414&atid=422032
-    # sourceforge.net/p/docutils/patches/108/
+    # workaround: some docutils nodes doesn't have source, line.
     if (isinstance(node, (
-            nodes.caption,
-            nodes.title,
-            nodes.rubric,
-            nodes.line,
-            nodes.image,
+            nodes.rubric,  # #1305 rubric directive
+            nodes.line,  # #1477 line node
+            nodes.image,  # #3093 image directive in substitution
+            nodes.field_name,  # #3335 field list syntax
     ))):
         node.source = find_source_node(node)
         node.line = 0  # need fix docutils to get `node.line`
@@ -216,6 +211,8 @@ def clean_astext(node):
     node = node.deepcopy()
     for img in node.traverse(nodes.image):
         img['alt'] = ''
+    for raw in node.traverse(nodes.raw):
+        raw.parent.remove(raw)
     return node.astext()
 
 
@@ -241,15 +238,15 @@ def process_index_entry(entry, targetid):
         main = 'main'
         entry = entry[1:].lstrip()
     for type in pairindextypes:
-        if entry.startswith(type+':'):
-            value = entry[len(type)+1:].strip()
+        if entry.startswith(type + ':'):
+            value = entry[len(type) + 1:].strip()
             value = pairindextypes[type] + '; ' + value
             indexentries.append(('pair', value, targetid, main, None))
             break
     else:
         for type in indextypes:
-            if entry.startswith(type+':'):
-                value = entry[len(type)+1:].strip()
+            if entry.startswith(type + ':'):
+                value = entry[len(type) + 1:].strip()
                 if type == 'double':
                     type = 'pair'
                 indexentries.append((type, value, targetid, main, None))
