@@ -343,6 +343,27 @@ class HTMLTranslator(BaseTranslator):
         if isinstance(node.parent, nodes.table):
             self.body.append('<span class="caption-text">')
 
+    def depart_title(self, node):
+        close_tag = self.context[-1]
+        if (self.permalink_text and self.builder.add_permalinks and
+           node.parent.hasattr('ids') and node.parent['ids']):
+            # add permalink anchor
+            if close_tag.startswith('</h'):
+                self.add_permalink_ref(node.parent, _('Permalink to this headline'))
+            elif close_tag.startswith('</a></h'):
+                self.body.append(u'</a><a class="headerlink" href="#%s" ' %
+                                 node.parent['ids'][0] +
+                                 u'title="%s">%s' % (
+                                     _('Permalink to this headline'),
+                                     self.permalink_text))
+            elif isinstance(node.parent, nodes.table):
+                self.body.append('</span>')
+                self.add_permalink_ref(node.parent, _('Permalink to this table'))
+        elif isinstance(node.parent, nodes.table):
+            self.body.append('</span>')
+
+        BaseTranslator.depart_title(self, node)
+
     # overwritten
     def visit_literal_block(self, node):
         if node.rawsource != node.astext():
@@ -433,7 +454,7 @@ class HTMLTranslator(BaseTranslator):
                 self.body.append(self.starttag(production, 'strong', ''))
                 self.body.append(lastname + '</strong> ::= ')
             elif lastname is not None:
-                self.body.append('%s     ' % (' '*len(lastname)))
+                self.body.append('%s     ' % (' ' * len(lastname)))
             production.walkabout(self)
             self.body.append('\n')
         self.body.append('</pre>\n')
@@ -593,7 +614,7 @@ class HTMLTranslator(BaseTranslator):
                     self.body.append(token)
                 else:
                     # protect runs of multiple spaces; the last one can wrap
-                    self.body.append('&#160;' * (len(token)-1) + ' ')
+                    self.body.append('&#160;' * (len(token) - 1) + ' ')
         else:
             if self.in_mailto and self.settings.cloak_email_addresses:
                 encoded = self.cloak_email(encoded)
@@ -677,24 +698,6 @@ class HTMLTranslator(BaseTranslator):
     def depart_abbreviation(self, node):
         self.body.append('</abbr>')
 
-    # overwritten (but not changed) to keep pair of visit/depart_term
-    def visit_term(self, node):
-        self.body.append(self.starttag(node, 'dt', ''))
-
-    # overwritten to add '</dt>' in 'depart_term' state.
-    def depart_term(self, node):
-        self.body.append('</dt>\n')
-
-    # overwritten to do not add '</dt>' in 'visit_definition' state.
-    def visit_definition(self, node):
-        self.generate_targets_for_listing(node)
-        self.body.append(self.starttag(node, 'dd', ''))
-        self.set_first_last(node)
-
-    # overwritten (but not changed) to keep pair of visit/depart_definition
-    def depart_definition(self, node):
-        self.body.append('</dd>\n')
-
     def visit_termsep(self, node):
         warnings.warn('sphinx.addnodes.termsep will be removed at Sphinx-1.6. '
                       'This warning is displayed because some Sphinx extension '
@@ -709,25 +712,6 @@ class HTMLTranslator(BaseTranslator):
     def depart_manpage(self, node):
         return self.depart_literal_emphasis(node)
 
-    def depart_title(self, node):
-        close_tag = self.context[-1]
-        if (self.permalink_text and self.builder.add_permalinks and
-           node.parent.hasattr('ids') and node.parent['ids']):
-            # add permalink anchor
-            if close_tag.startswith('</h'):
-                self.add_permalink_ref(node.parent, _('Permalink to this headline'))
-            elif close_tag.startswith('</a></h'):
-                self.body.append(u'</a><a class="headerlink" href="#%s" ' %
-                                 node.parent['ids'][0] +
-                                 u'title="%s">%s' % (
-                                     _('Permalink to this headline'),
-                                     self.permalink_text))
-            elif isinstance(node.parent, nodes.table):
-                self.body.append('</span>')
-                self.add_permalink_ref(node.parent, _('Permalink to this table'))
-
-        BaseTranslator.depart_title(self, node)
-
     # overwritten to add even/odd classes
 
     def visit_table(self, node):
